<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Agraïments</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Ajudeu-nos</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>és una aplicació multiplataforma per a la creació ràpida de captures de pantalla del vostre escriptori.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>És una aplicació lleugera i potent, escrita en Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt %1</source>
        <translation>usant les Qt %1</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>Lloc web - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="108"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>Llicencia sota el &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="112"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Drets d&apos;autor &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="119"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Podeu unir-vos a nosaltres i ajudar-nos si voleu. Aquesta és una invitació si us agrada aquesta aplicació.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="122"/>
        <source>What you can do?</source>
        <translation>Què podeu fer?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="125"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Traduir ScreenGrab a altres llengües</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Make suggestions for next releases</source>
        <translation>Fer suggeriments per als pròxims llançaments</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Report bugs and issues</source>
        <translation>Informar dels errors i de les incidències</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="130"/>
        <source>Bug tracker</source>
        <translation>Seguiment d&apos;errors</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="140"/>
        <source>Translate:</source>
        <translation>Traducció:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source> Brazilian Portuguese translation</source>
        <translation> Traducció al portuguès de Brasil</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source>Marcio Moraes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source> Ukrainian translation</source>
        <translation> Traducció a l&apos;ucraïnès</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source>Gennadi Motsyo</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="148"/>
        <source> Spanish translation</source>
        <translation> Traducció a l&apos;espanyol</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source>Burjans L García D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="151"/>
        <source> Italian translation</source>
        <translation> Traducció a l&apos;italià</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="155"/>
        <source>Testing:</source>
        <translation>Proves:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="157"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Admissió de monitors duals i altres a Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support in Linux</source>
        <translation>Admissió de monitors duals a Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>Construcció win32 [Windows XP i 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>Construcció win32 antiga [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>win32-build [Windows 7]</source>
        <translation>Construcció win32 [Windows 7]</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="186"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>No existeix el directori %1. Voleu crear-lo?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="187"/>
        <location filename="../src/core/ui/configwidget.cpp" line="275"/>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="263"/>
        <source>Select directory</source>
        <translation>Selecciona el directori</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="274"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Voleu restablir els ajusts als valors predeterminats?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="332"/>
        <source>Example: </source>
        <translation>Exemple: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="377"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>Aquesta tecla ja s&apos;utilitza a ScreenGrab. Seleccioneu-ne una altra.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="395"/>
        <source>This key is not supported on your system!</source>
        <translation>Aquesta tecla no està admesa al vostre sistema!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="415"/>
        <source>Error</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="62"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>és una aplicació multiplataforma per a la creació ràpida de captures de pantalla del vostre escriptori.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Feu captures de pantalla a pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a screenshot of the active window</source>
        <translation>Feu una captura de pantalla de la finestra activa</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Feu captures de pantalla d&apos;una selecció de la pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="78"/>
        <source>Run the application with a hidden main window</source>
        <translation>Executeu l&apos;aplicació amb una finestra principal oculta</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="455"/>
        <source>Saved</source>
        <translation>Desat</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="455"/>
        <source>Saved to </source>
        <translation>Desat a </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="477"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>El nom del fitxer desat es copia al porta-retalls</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="483"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>El camí al fitxer desat es copia al porta-retalls</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="505"/>
        <source>Copied</source>
        <translation>Copiat</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="505"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>La captura de pantalla es copia al porta-retalls</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Tipus de la captura de pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Àrea de la pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>Última àrea seleccionada</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>Retard:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Retard en segons abans de prendre la captura de pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>Zoom a l&apos;àrea al voltant del ratolí</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>Sense decoració de finestra</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>Inclou el punter del ratolí</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>Barra d&apos;eines</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>Options</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
        <source>Help</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="341"/>
        <source>Screenshot </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="345"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Doble clic per obrir la captura de pantalla al visualitzador d&apos;imatges extern predeterminat</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="354"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="485"/>
        <source>Hide</source>
        <translation>Oculta</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="492"/>
        <source>Show</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="545"/>
        <source>%1 Files</source>
        <translation>%1 fitxers</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="567"/>
        <source>Save As...</source>
        <translation>Desa com...</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="175"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Feu clic i arrossegueu per dibuixar un rectangle,
clic dret per ajustar-se a les vores,
doble clic o premeu Enter
per fer una captura de pantalla.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="207"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 píxels </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Edició externa</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Edita a...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>Quant a Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="601"/>
        <source>Options</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Principal</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Avançat</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>Safata del sistema</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>Directori de desament predeterminat</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>Camí al directori predeterminat dels desaments per seleccionar-ne un</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Navega pel sistema de fitxers</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Navega</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>Fitxer predeterminat</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Nom de fitxer predeterminat</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Format d&apos;imatge predeterminat de desament</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Copia el nom del fitxer al porta-retalls quan es desa</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>No ho copiïs</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>Copia només el nom del fitxer</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>Copia el camí complet al fitxer</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Qualitat d&apos;imatge</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Qualitat d&apos;imatge (1 - fitxer petit, 100 - alta qualitat)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Inserció de la data actual al nom del fitxer desat</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>Insereix la data i hora actual al nom del fitxer</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Plantilla: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Exemple: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Desament automàtic de captures de pantalla en el procés d&apos;agafament</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Desa automàticament la captura de pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Desa primer la captura de pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Permet l&apos;execució de diverses còpies de ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Permet diverses instàncies de ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>Obre al visualitzador extern amb el doble clic</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Habilita el visualitzador extern</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Si no està marcat, l&apos;àrea seleccionada
es pot fer més gran per ajustar-se a les vores exteriors</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="411"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>Ajusta a les vores dins de l&apos;àrea seleccionada prement botó dret del ratolí</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="449"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Mostra ScreenGrab a la safata del sistema</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="458"/>
        <source>Tray messages:</source>
        <translation>Missatges de la safata:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="471"/>
        <source>Tray messages display mode</source>
        <translation>Mode de visualització dels missatges de la safata</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="475"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="480"/>
        <source>Tray mode</source>
        <translation>Mode safata</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="485"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="497"/>
        <source>Time of display tray messages</source>
        <translation>Temps de visualització dels missatges de la safata</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="513"/>
        <source>Time to display tray messages</source>
        <translation>Temps per mostrar el missatges de la safata</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="534"/>
        <source>Minimize to tray on click close button</source>
        <translation>Minimitza a la safata amb el clic al botó de tancar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="537"/>
        <source>Minimize to tray when closing</source>
        <translation>Minimitza a la safata quan s&apos;està tancant</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="576"/>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="581"/>
        <source>Shortcut</source>
        <translation>Drecera</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="586"/>
        <source>New screen</source>
        <translation>Pantalla nova</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="591"/>
        <source>Save screen</source>
        <translation>Desa la pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="596"/>
        <source>Copy screen</source>
        <translation>Copia la pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="606"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="611"/>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="621"/>
        <source>Selected shortcut:</source>
        <translation>Drecera seleccionada:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="628"/>
        <source>Not defined</source>
        <translation>Sense definir</translation>
    </message>
</context>
</TS>
